#define _CRT_SECURE_NO_WARNINGS

#include <iostream>
#include <cstdio>
#include <vector>
#include <algorithm>
#include <queue>
#include <string>
#include <cstring>
#include <map>
#include <set>
#include <unordered_map>
#include <unordered_set>
#include <cmath>
#include <ctime>
#include <chrono>
#include <random>

using namespace std;

typedef long long LL;

mt19937 rnd;
struct CT {
  int x;
  int y;
  int val;
  
  CT *left, *right;

  CT(int x, int val = 0) : y(rnd()), x(x), val(val) {
    left = nullptr, right = nullptr;
  }
};

CT* merge(CT* &left, CT* &right) {
  if (left == nullptr) return right;
  if (right == nullptr) return left;

  if (left->y > right->y) {
    left->right = merge(left->right, right);
    return left;
  }
  else {
    right->left = merge(left, right->left);
    return right;
  }
}

pair<CT*, CT*> split(CT* &root, int x) { // L <= | > R
  if (root == nullptr) return{ nullptr, nullptr };

  if (root->x <= x) {
    pair<CT*, CT*> s = split(root->right, x);
    root->right = s.first;
    s.first = root;
    return s;
  }
  else {
    pair<CT*, CT*> s = split(root->left, x);
    root->left = s.second;
    s.second = root;
    return s;
  }
}

CT* get(CT* &root, int x) {
  if (root == nullptr) return nullptr;
  if (root->x == x) return root;
  if (root->x < x) return get(root->right, x);
  return get(root->left, x);
}

int inc(CT *&root, int x) {
  if (root == nullptr) {
    root = new CT(x, 2);
    return 2;
  }

  CT* g = get(root, x);
  if (g != nullptr) {
    return ++(g->val);
  }

  pair<CT*, CT*> s = split(root, x);
  CT *tmp = new CT(x, 2);
  root = merge(s.first, tmp);
  root = merge(root, s.second);
  return 2;
}

void erase(CT* &root, int L) {
  if (root == nullptr) return;
  pair<CT*, CT*> s1;
  s1 = split(root, L);
  root = s1.first;
}

void solve() {
  rnd.seed(2017);
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
  cin.tie(0);
  cin.sync_with_stdio(0);

  int n;
  cin >> n;

  vector<int> a(n + 1);

  for (int i = 1; i <= n; ++i) {
    cin >> a[i];
  }

  int L = 0, R = n;

  while (R - L > 1) {
    int k = (L + R) / 2;

    bool ok = 1;

    CT *root = nullptr;
    map<int, int> digits;

    for (int i = 1; i <= n && ok; ++i) {
      if (a[i] > a[i - 1]) {
        erase(root, a[i - 1]);
        continue;
      }
      if (a[i] <= a[i - 1]) {
        int val = inc(root, a[i]);
        
        int j = a[i];
        while (val > k) {
          if (j == 1) {
            ok = false;
            break;
          }
          get(root, j)->val -= k;
          val = inc(root, j - 1);
          --j;
        }
      }
    }

    if (ok) R = k;
    else L = k;
  }

  cout << R << endl;
}

void generate() {
  mt19937 rnd;

  static int gencnt = 0;

  rnd.seed(2017 + gencnt++);

  freopen("input.txt", "w", stdout);
  const int n = 100000;
  const int MAXLEN = (int)2e5;
  cout << n << endl;

  for (int i = 0; i < n; ++i)
    cout << 1 + rnd() % MAXLEN << ' ';

  fclose(stdout);
}

int main() {
#define _STRESS
#ifdef _STRESS
  int tests = 100, cur = 0;
  while (cur++ < tests) {
    generate();
    std::chrono::time_point<std::chrono::system_clock> start, end;
    start = std::chrono::system_clock::now();
    solve();
    fclose(stdin);
    fclose(stdout);
    end = std::chrono::system_clock::now();
    std::chrono::duration<double> elapsed_seconds = end - start;
    cerr << "elapsed " << elapsed_seconds.count() << "s\n";
    if (elapsed_seconds.count() > 2) {
      cerr << "KEK" << '\n';
      break;
    }
  }
#else
  solve();
#endif

  return 0;
}