#define _CRT_SECURE_NO_WARNINGS

#include <iostream>
#include <cstdio>
#include <vector>
#include <algorithm>
#include <queue>
#include <string>
#include <cstring>
#include <map>
#include <set>
#include <unordered_map>
#include <unordered_set>
#include <cmath>
#include <ctime>

using namespace std;

typedef long long LL;

struct ST {
  LL mx;

  ST *left, *right;

  ST(int L, int R) {
    left = right = nullptr;
    mx = 0;
    if (L != R) {
      int mid = (L + R) / 2;
      left = new ST(L, mid);
      right = new ST(mid + 1, R);
    }
  }

  ST(ST *left, ST *right) :left(left), right(right) {
    if (left != nullptr) {
      mx = max(left->mx, right->mx);
    }
    else {
      mx = 0;
    }
  }
  ST(LL mx) : mx(mx), left(nullptr), right(nullptr) {}
};

ST* add(ST *root, int L, int R, int ql, int qr, LL dsum) {
  if (root == nullptr || L > R || ql > R || qr < L) return root;
  if (L == R) {
    return new ST(root->mx + dsum);
  }

  int mid = (L + R) / 2;

  return new ST(add(root->left, L, mid, ql, qr, dsum), add(root->right, mid + 1, R, ql, qr, dsum));  
}



int main() {
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
  cin.tie(0);
  cin.sync_with_stdio(0);
  
  int n, k;
  cin >> n >> k;

  struct KFC {
    int L, R, p;

    bool operator<(const KFC &t) const {
      return R != t.R ? R < t.R : L < t.L;
    }
  };

  vector<KFC> kfcs(n);
  for (int i = 0; i < n; ++i) {
    cin >> kfcs[i].L >> kfcs[i].R >> kfcs[i].p;
    if (kfcs[i].L > k) {
      swap(kfcs[i], kfcs.back());
      kfcs.pop_back();
      i--;
      n--;
      continue;
    } 
    kfcs[i].R = min(kfcs[i].R, k);
  }

  enum {
    BEGIN, 
    KEK,
    END
  };

  struct Event {
    char type;
    int pos;
    int id;

    bool operator<(const Event &e) const {
      return pos != e.pos ? pos < e.pos : type < e.type;
    }
  };

  vector<Event> events;
  events.reserve(2 + n * 4);

  events.push_back({ KEK, 1, -1 });
  events.push_back({ KEK, k, -1 });

  for (int i = 0; i < n; ++i) {
    events.push_back({ BEGIN, kfcs[i].L, i });
    events.push_back({ END, kfcs[i].R, i });
    if (kfcs[i].L > 1) events.push_back({ KEK, kfcs[i].L - 1, i });
    if (kfcs[i].R < k) events.push_back({ KEK, kfcs[i].R + 1, i });
  }

  sort(events.begin(), events.end());

  int scanpoint = 1, balance = 0;
  int prevpos = 1;
  for (auto e : events) {
    if (prevpos != e.pos) {
      prevpos = e.pos;
      scanpoint++;
    }
    if (e.type == KEK) {
      if (!balance) {
        cout << -1 << endl;
        return 0;
      }
    }
    else if (e.type == BEGIN) {
      balance++;
      kfcs[e.id].L = scanpoint;
    }
    else if (e.type == END) {
      if (!balance) {
        cout << -1 << endl;
        return 0;
      }
      balance--;
      kfcs[e.id].R = scanpoint;
    }
  }

  sort(kfcs.begin(), kfcs.end());
  
  vector<ST*> versions;

  kfcs.insert(kfcs.begin(), KFC{ 0, 0, 0 });
  versions.push_back(new ST(1, scanpoint));

  for (int i = 1; i <= n; ++i) {
    ST *best = nullptr;
    LL curmx = (LL)1e18;
    for (int j = i - 1; j > -1; --j) {
      if (kfcs[j].R + 1 < kfcs[i].L) break;
      ST *tmp = add(versions[j], 1, scanpoint, kfcs[i].L, kfcs[i].R, kfcs[i].p);
      if (tmp->mx < curmx) {
        best = tmp;
        curmx = tmp->mx;
      }
    }
    versions.push_back(best);
  }

  LL ans = (LL)1e18;
  for (int i = (int)versions.size() - 1; i > -1; --i) {
    if (kfcs[i].R != scanpoint) break;
    ans = min(ans, versions[i]->mx);
  }
  
  cout << ans << endl;

  return 0;
}
