#include <iostream>
#include <vector>
#include <set>
#include <vector>
#include <algorithm>
#include <cstdio>
#include <cstdlib>
#include <functional>
#include <climits>
#include <cassert>
#include <map>
#include <set>

using namespace std;

typedef unsigned int index;

struct Item
{
	Item *l, *r;
	pair<int, int> key;
	int prior;
	int min;
	int deep;
	Item(): l(NULL), r(NULL), prior(rand() % 1000000){}
};

typedef Item * Pitem;

void upd(Pitem &t)
{
	if (t == NULL)
		return;
	t->min = t->key.second;
	if (t->l != NULL)
	{
		t->min = min(t->min, t->l->min);
	}
	if (t->r != NULL)
	{
		t->min = min(t->min, t->r->min);
	}
}


void split(Pitem t, Pitem &l, Pitem &r, int key)
{
	if (t == NULL)
	{
		l = NULL;
		r = NULL;
		return;
	}
	if (t->key.first < key)
	{
		split(t->r, t->r, r, key);
		l = t;
		upd(l);
	}
	else
	{
		split(t->l, l, t->l, key);
		r = t;
		upd(r);
	}
}

void merge(Pitem l, Pitem r, Pitem &t)
{
	if (l == NULL)
		t = r;
	else if (r == NULL)
		t = l;
	else
	{
		if (l->prior < r->prior)
		{
			merge(l->r, r, l->r);
			t = l;
		}
		else
		{
			merge(l, r->l, r->l);
			t = r;
		}
	}
	upd(t);
}

void scew_split(Pitem t, Pitem &l, Pitem &r, int key)
{
	if (t == NULL)
	{
		l = NULL;
		r = NULL;
		return;
	}
	if (t->key.first < key or (t->key.first == key and rand() % 2))
	{
		scew_split(t->r, t->r, r, key);
		l = t;
		upd(l);
	}
	else
	{
		scew_split(t->l, l, t->l, key);
		r = t;
		upd(r);
	}
}

void insert(Pitem &t, Pitem it)
{
	if (t == NULL)
		t = it;
	else
	{
		if (it->prior < t->prior)
		{
			scew_split(t, it->l, it->r, it->key.first);
			t = it;
		}
		else
		{
			if (it->key.first < t->key.first or (it->key.first == t->key.first and rand() % 2))
			{
				insert(t->l, it);
			}
			else
			{
				insert(t->r, it);
			}
		}
	}
	upd(t);
}

void clear(Pitem &t, int add)
{
	if (t == NULL)
		return;
	if (t->min + add > 0)
		return;
	clear(t->l, add);
	clear(t->r, add);
	if (t->key.second + add <= 0)
	{
		merge(t->l, t->r, t);
	}
	upd(t);
}

int cnt(Pitem t)
{
	if (t == NULL)
		return 0;
	return max(cnt(t->l), cnt(t->r)) + 1;
}

bool check(int max_v, int k, const vector<pair<pair<int, int>, int>> &seg, Item *pred)
{
	multiset<pair<int, pair<int, int>>> fld;
	fld.insert({0, {0, 1}});
	int yk = -1;
	Pitem root = NULL;
	int add = 0;
	index last = 0;
	for (auto i: seg)
	{
		while (yk < i.first.first)
		{
			while (fld.begin() != fld.end() and fld.begin()->first <= i.first.first)
			{
				int nk;
				nk = fld.begin()->first;
				add -= nk - yk;
				clear(root, add);
				pred[last] = Item();
				Pitem nw = &pred[last];
				last++;
				nw->key = {fld.begin()->second.first, fld.begin()->second.second - add};
				upd(nw);
				insert(root, nw);
				yk = nk;
				fld.erase(fld.begin());
			}
			int nk = i.first.first;
			add -= nk - yk;
			clear(root, add);
			yk = nk;
		}
		Pitem l = NULL, r = NULL;
		split(root, l, r, max_v - i.second + 1);
		int mn = (l == NULL ? (int)1e9 + 500 : l->min + add);
		merge(l, r, root);
		if (yk + mn <= i.first.second + 1)
		{
			fld.insert({yk + mn, {i.second, i.first.second - yk - mn + 1}});
			fld.insert({yk + mn, {i.second, i.first.second - yk - mn + 1}});
			fld.insert({i.first.second + 1, {0, 1}});
		}
	}
	if (fld.find({k, {0, 1}}) != fld.end())
		return true;
	else
		return false;
}

int main() 
{
	srand((index)time(0));
#ifdef ONPC
	assert(freopen("a.in", "r", stdin));
	assert(freopen("a.out", "w", stdout));
#else
#endif
	ios::sync_with_stdio(false);
	size_t n;
	int k;
	cin >> n >> k;
	Item *pred = new Item[300000];
	vector<pair<pair<int, int>, int>> seg(n);
	for (index i = 0; i < n; i++)
	{
		cin >> seg[i].first.first >> seg[i].first.second >> seg[i].second;
		seg[i].first.first--, seg[i].first.second--;
	}
	sort(seg.begin(), seg.end());
	long long l = -1, r = 2e9 + 5;
	while (r - l > 1)
	{
		long long m = (l + r) / 2;
		if (check((int)m, k, seg, pred))
			r = m;
		else
			l = m;

	}
	if (r == (long long)2e9 + 5)
		cout << -1 << endl;
	else
		cout << r << endl;
}
